# -*- coding: utf-8 -*-


class ApiExceptionBase(Exception):
    """
    @type message: string
    @param message: error describe
    """
    def __init__(self, message):
        self.message = message

    def get_info(self):
        return 'Error Message: %s\n' % (self.message)

    def __str__(self):
        return "ApiExceptionBase  %s" % (self.get_info())


class ApiClientParamException(ApiExceptionBase):
    def __init__(self, message):
        ApiExceptionBase.__init__(self, message)

    def __str__(self):
        return "ApiClientException  %s" % (self.get_info())


class ApiClientNetworkException(ApiExceptionBase):
    """ @note: client network exception
    """
    def __init__(self, message):
        ApiExceptionBase.__init__(self, message)

    def __str__(self):
        return "ApiClientNetworkException  %s" % (self.get_info())


class ApiServerNetworkException(ApiExceptionBase):
    """ @note: api server exception
    """
    def __init__(self, status=200, header=None, data=""):
        if header is None:
            header = {}
        self.status = status
        self.header = header
        self.data = data

    def __str__(self):
        headers = "\n".join("%s: %s" % (k, v) for k, v in self.header.items())
        return ("ApiServerNetworkException Status: %s\nHeader: %s\nData: %s\n"
                % (self.status, headers, self.data))



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class CreateWeappQRUrlRequest(AbstractModel):
    """CreateWeappQRUrl请求参数结构体

    """

    def __init__(self):
        """
        :param SessionKey: 代理角色临时密钥的Token\n        :type SessionKey: str\n        """
        self.SessionKey = None


    def _deserialize(self, params):
        self.SessionKey = params.get("SessionKey")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateWeappQRUrlResponse(AbstractModel):
    """CreateWeappQRUrl返回参数结构体

    """

    def __init__(self):
        """
        :param Url: 渠道备案小程序二维码\n        :type Url: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Url = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Url = params.get("Url")
        self.RequestId = params.get("RequestId")


class DescribeGetAuthInfoRequest(AbstractModel):
    """DescribeGetAuthInfo请求参数结构体

    """


class DescribeGetAuthInfoResponse(AbstractModel):
    """DescribeGetAuthInfo返回参数结构体

    """

    def __init__(self):
        """
        :param IsTenPayMasked: 实名认证状态：0未实名，1已实名\n        :type IsTenPayMasked: str\n        :param IsAuthenticated: 实名认证类型：0个人，1企业\n        :type IsAuthenticated: str\n        :param Type: 认证类型，个人0，企业1\n        :type Type: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.IsTenPayMasked = None
        self.IsAuthenticated = None
        self.Type = None
        self.RequestId = None


    def _deserialize(self, params):
        self.IsTenPayMasked = params.get("IsTenPayMasked")
        self.IsAuthenticated = params.get("IsAuthenticated")
        self.Type = params.get("Type")
        self.RequestId = params.get("RequestId")


class SyncIcpOrderWebInfoRequest(AbstractModel):
    """SyncIcpOrderWebInfo请求参数结构体

    """

    def __init__(self):
        """
        :param IcpOrderId: 备案ICP订单号\n        :type IcpOrderId: str\n        :param SourceWebId: 订单里的webId\n        :type SourceWebId: str\n        :param TargetWebIds: 订单里的webId 数组(如果传入的webIds含有 订单中不包含的webId，会自动跳过)\n        :type TargetWebIds: list of str\n        :param SyncFields: 网站信息字段名 数组\n        :type SyncFields: list of str\n        :param CheckSamePerson: 是否先判断同步的网站负责人是否一致 (这里会判断 sitePersonName, sitePersonCerType,sitePersonCerNum三个字段完全一致)  默认:true. 非必要 不建议关闭修改该参数默认值\n        :type CheckSamePerson: bool\n        """
        self.IcpOrderId = None
        self.SourceWebId = None
        self.TargetWebIds = None
        self.SyncFields = None
        self.CheckSamePerson = None


    def _deserialize(self, params):
        self.IcpOrderId = params.get("IcpOrderId")
        self.SourceWebId = params.get("SourceWebId")
        self.TargetWebIds = params.get("TargetWebIds")
        self.SyncFields = params.get("SyncFields")
        self.CheckSamePerson = params.get("CheckSamePerson")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SyncIcpOrderWebInfoResponse(AbstractModel):
    """SyncIcpOrderWebInfo返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class CdsAuditInstance(AbstractModel):
    """数据安全产品实例信息

    """

    def __init__(self):
        """
        :param InstanceId: 实例ID\n        :type InstanceId: str\n        :param AppId: 用户AppId\n        :type AppId: str\n        :param Uin: 用户Uin\n        :type Uin: str\n        :param ProjectId: 项目ID\n        :type ProjectId: int\n        :param RenewFlag: 续费标识\n        :type RenewFlag: int\n        :param Region: 所属地域\n        :type Region: str\n        :param PayMode: 付费模式（数据安全审计只支持预付费：1）\n        :type PayMode: int\n        :param Status: 实例状态： 0，未生效；1：正常运行； 2：被隔离； 3，已过期\n        :type Status: int\n        :param IsolatedTimestamp: 实例被隔离时间，格式：yyyy-mm-dd HH:ii:ss\n        :type IsolatedTimestamp: str\n        :param CreateTime: 实例创建时间，格式： yyyy-mm-dd HH:ii:ss\n        :type CreateTime: str\n        :param ExpireTime: 实例过期时间，格式：yyyy-mm-dd HH:ii:ss\n        :type ExpireTime: str\n        :param InstanceName: 实例名称
注意：此字段可能返回 null，表示取不到有效值。\n        :type InstanceName: str\n        :param PublicIp: 实例公网IP
注意：此字段可能返回 null，表示取不到有效值。\n        :type PublicIp: str\n        :param PrivateIp: 实例私网IP
注意：此字段可能返回 null，表示取不到有效值。\n        :type PrivateIp: str\n        :param InstanceType: 实例类型（版本）\n        :type InstanceType: str\n        :param Pdomain: 实例域名
注意：此字段可能返回 null，表示取不到有效值。\n        :type Pdomain: str\n        """
        self.InstanceId = None
        self.AppId = None
        self.Uin = None
        self.ProjectId = None
        self.RenewFlag = None
        self.Region = None
        self.PayMode = None
        self.Status = None
        self.IsolatedTimestamp = None
        self.CreateTime = None
        self.ExpireTime = None
        self.InstanceName = None
        self.PublicIp = None
        self.PrivateIp = None
        self.InstanceType = None
        self.Pdomain = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.AppId = params.get("AppId")
        self.Uin = params.get("Uin")
        self.ProjectId = params.get("ProjectId")
        self.RenewFlag = params.get("RenewFlag")
        self.Region = params.get("Region")
        self.PayMode = params.get("PayMode")
        self.Status = params.get("Status")
        self.IsolatedTimestamp = params.get("IsolatedTimestamp")
        self.CreateTime = params.get("CreateTime")
        self.ExpireTime = params.get("ExpireTime")
        self.InstanceName = params.get("InstanceName")
        self.PublicIp = params.get("PublicIp")
        self.PrivateIp = params.get("PrivateIp")
        self.InstanceType = params.get("InstanceType")
        self.Pdomain = params.get("Pdomain")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DbauditTypesInfo(AbstractModel):
    """数据安全审计产品规格信息

    """

    def __init__(self):
        """
        :param InstanceVersionName: 规格描述\n        :type InstanceVersionName: str\n        :param InstanceVersionKey: 规格名称\n        :type InstanceVersionKey: str\n        :param Qps: 最大吞吐量\n        :type Qps: int\n        :param MaxInstances: 最大实例数\n        :type MaxInstances: int\n        :param InsertSpeed: 入库速率（每小时）\n        :type InsertSpeed: int\n        :param OnlineStorageCapacity: 最大在线存储量，单位：条\n        :type OnlineStorageCapacity: int\n        :param ArchivingStorageCapacity: 最大归档存储量，单位：条\n        :type ArchivingStorageCapacity: int\n        """
        self.InstanceVersionName = None
        self.InstanceVersionKey = None
        self.Qps = None
        self.MaxInstances = None
        self.InsertSpeed = None
        self.OnlineStorageCapacity = None
        self.ArchivingStorageCapacity = None


    def _deserialize(self, params):
        self.InstanceVersionName = params.get("InstanceVersionName")
        self.InstanceVersionKey = params.get("InstanceVersionKey")
        self.Qps = params.get("Qps")
        self.MaxInstances = params.get("MaxInstances")
        self.InsertSpeed = params.get("InsertSpeed")
        self.OnlineStorageCapacity = params.get("OnlineStorageCapacity")
        self.ArchivingStorageCapacity = params.get("ArchivingStorageCapacity")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDasbImageIdsRequest(AbstractModel):
    """DescribeDasbImageIds请求参数结构体

    """


class DescribeDasbImageIdsResponse(AbstractModel):
    """DescribeDasbImageIds返回参数结构体

    """

    def __init__(self):
        """
        :param BaseImageId: 基础镜像ID\n        :type BaseImageId: str\n        :param AiImageId: AI镜像ID\n        :type AiImageId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.BaseImageId = None
        self.AiImageId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.BaseImageId = params.get("BaseImageId")
        self.AiImageId = params.get("AiImageId")
        self.RequestId = params.get("RequestId")


class DescribeDbauditInstanceTypeRequest(AbstractModel):
    """DescribeDbauditInstanceType请求参数结构体

    """


class DescribeDbauditInstanceTypeResponse(AbstractModel):
    """DescribeDbauditInstanceType返回参数结构体

    """

    def __init__(self):
        """
        :param DbauditTypesSet: 数据安全审计产品规格信息列表\n        :type DbauditTypesSet: list of DbauditTypesInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.DbauditTypesSet = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("DbauditTypesSet") is not None:
            self.DbauditTypesSet = []
            for item in params.get("DbauditTypesSet"):
                obj = DbauditTypesInfo()
                obj._deserialize(item)
                self.DbauditTypesSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeDbauditInstancesRequest(AbstractModel):
    """DescribeDbauditInstances请求参数结构体

    """

    def __init__(self):
        """
        :param SearchRegion: 查询条件地域\n        :type SearchRegion: str\n        :param Limit: 限制数目，默认10， 最大50\n        :type Limit: int\n        :param Offset: 偏移量，默认1\n        :type Offset: int\n        """
        self.SearchRegion = None
        self.Limit = None
        self.Offset = None


    def _deserialize(self, params):
        self.SearchRegion = params.get("SearchRegion")
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeDbauditInstancesResponse(AbstractModel):
    """DescribeDbauditInstances返回参数结构体

    """

    def __init__(self):
        """
        :param TotalCount: 总实例数\n        :type TotalCount: int\n        :param CdsAuditInstanceSet: 数据安全审计实例信息列表\n        :type CdsAuditInstanceSet: list of CdsAuditInstance\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalCount = None
        self.CdsAuditInstanceSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("CdsAuditInstanceSet") is not None:
            self.CdsAuditInstanceSet = []
            for item in params.get("CdsAuditInstanceSet"):
                obj = CdsAuditInstance()
                obj._deserialize(item)
                self.CdsAuditInstanceSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeDbauditUsedRegionsRequest(AbstractModel):
    """DescribeDbauditUsedRegions请求参数结构体

    """


class DescribeDbauditUsedRegionsResponse(AbstractModel):
    """DescribeDbauditUsedRegions返回参数结构体

    """

    def __init__(self):
        """
        :param RegionSet: 可售卖地域信息列表\n        :type RegionSet: list of RegionInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RegionSet = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("RegionSet") is not None:
            self.RegionSet = []
            for item in params.get("RegionSet"):
                obj = RegionInfo()
                obj._deserialize(item)
                self.RegionSet.append(obj)
        self.RequestId = params.get("RequestId")


class InquiryPriceDbauditInstanceRequest(AbstractModel):
    """InquiryPriceDbauditInstance请求参数结构体

    """

    def __init__(self):
        """
        :param InstanceVersion: 实例规格，取值范围： cdsaudit，cdsaudit_adv， cdsaudit_ent 分别为合规版，高级版，企业版\n        :type InstanceVersion: str\n        :param InquiryType: 询价类型： renew，续费；newbuy，新购\n        :type InquiryType: str\n        :param TimeSpan: 购买实例的时长。取值范围：1（y/m），2（y/m）,，3（y/m），4（m）， 5（m），6（m）， 7（m），8（m），9（m）， 10（m）\n        :type TimeSpan: int\n        :param TimeUnit: 购买时长单位，y：年；m：月\n        :type TimeUnit: str\n        :param ServiceRegion: 实例所在地域\n        :type ServiceRegion: str\n        """
        self.InstanceVersion = None
        self.InquiryType = None
        self.TimeSpan = None
        self.TimeUnit = None
        self.ServiceRegion = None


    def _deserialize(self, params):
        self.InstanceVersion = params.get("InstanceVersion")
        self.InquiryType = params.get("InquiryType")
        self.TimeSpan = params.get("TimeSpan")
        self.TimeUnit = params.get("TimeUnit")
        self.ServiceRegion = params.get("ServiceRegion")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InquiryPriceDbauditInstanceResponse(AbstractModel):
    """InquiryPriceDbauditInstance返回参数结构体

    """

    def __init__(self):
        """
        :param TotalPrice: 总价，单位：元\n        :type TotalPrice: float\n        :param RealTotalCost: 真实价钱，预支费用的折扣价，单位：元\n        :type RealTotalCost: float\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.TotalPrice = None
        self.RealTotalCost = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalPrice = params.get("TotalPrice")
        self.RealTotalCost = params.get("RealTotalCost")
        self.RequestId = params.get("RequestId")


class ModifyDbauditInstancesRenewFlagRequest(AbstractModel):
    """ModifyDbauditInstancesRenewFlag请求参数结构体

    """

    def __init__(self):
        """
        :param InstanceId: 实例ID\n        :type InstanceId: str\n        :param AutoRenewFlag: 0，表示默认状态(用户未设置，即初始状态)；1，表示自动续费；2，表示明确不自动续费\n        :type AutoRenewFlag: int\n        """
        self.InstanceId = None
        self.AutoRenewFlag = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.AutoRenewFlag = params.get("AutoRenewFlag")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyDbauditInstancesRenewFlagResponse(AbstractModel):
    """ModifyDbauditInstancesRenewFlag返回参数结构体

    """

    def __init__(self):
        """
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class RegionInfo(AbstractModel):
    """数盾地域信息

    """

    def __init__(self):
        """
        :param RegionId: 地域ID\n        :type RegionId: int\n        :param Region: 地域名称\n        :type Region: str\n        :param RegionName: 地域描述\n        :type RegionName: str\n        :param RegionState: 地域可用状态\n        :type RegionState: int\n        """
        self.RegionId = None
        self.Region = None
        self.RegionName = None
        self.RegionState = None


    def _deserialize(self, params):
        self.RegionId = params.get("RegionId")
        self.Region = params.get("Region")
        self.RegionName = params.get("RegionName")
        self.RegionState = params.get("RegionState")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# CAM签名/鉴权错误，未授权的操作。
AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 互联IP错误。
INVALIDPARAMETER_ADDRESSERROR = 'InvalidParameter.AddressError'

# 物理专线不属于该账号。
INVALIDPARAMETER_DIRECTCONNECTIDISNOTUIN = 'InvalidParameter.DirectConnectIdIsNotUin'

# 该账号ID不存在。
INVALIDPARAMETER_UINISNOTEXIST = 'InvalidParameter.UinIsNotExist'

# vlan冲突。
INVALIDPARAMETER_VLANCONFLICT = 'InvalidParameter.VlanConflict'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# vlan冲突。
INVALIDPARAMETERVALUE_VLANCONFLICT = 'InvalidParameterValue.VlanConfLict'

# 超过配额限制。
LIMITEXCEEDED = 'LimitExceeded'

# 物理专线数已达上限。
LIMITEXCEEDED_DIRECTCONNECTLIMITEXCEEDED = 'LimitExceeded.DirectConnectLimitExceeded'

# 物理专线的专用通道数已达上限。
LIMITEXCEEDED_DIRECTCONNECTTUNNELLIMITEXCEEDED = 'LimitExceeded.DirectConnectTunnelLimitExceeded'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 资源被占用。
RESOURCEINUSE = 'ResourceInUse'

# 物理专线的vpc已经存在。
RESOURCEINUSE_DCVPCISEXIST = 'ResourceInUse.DcVpcIsExist'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 专用通道不存在。
RESOURCENOTFOUND_DIRECTCONNECTTUNNELIDISNOTEXIST = 'ResourceNotFound.DirectConnectTunnelIdIsNotExist'

# 资源不可用。
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# 对不起您的帐号已欠费，欠费状态下无法开通产品，请您先行充值。
RESOURCEUNAVAILABLE_INSUFFICIENTBALANCE = 'ResourceUnavailable.InsufficientBalance'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# 未知参数错误。
UNKNOWNPARAMETER = 'UnknownParameter'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# 不允许创建跨境专用通道，请您联系我们。
UNSUPPORTEDOPERATION_CROSSBORDERDIRECTCONNECTTUNNEL = 'UnsupportedOperation.CrossBorderDirectConnectTunnel'

# 状态冲突。
UNSUPPORTEDOPERATION_STATECONFLICT = 'UnsupportedOperation.StateConfLict'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class DetectFraudKOLRequest(AbstractModel):
    """DetectFraudKOL请求参数结构体

    """

    def __init__(self):
        """
        :param BspData: 业务数据\n        :type BspData: :class:`tencentcloud.taf.v20200210.models.InputKolBspData`\n        """
        self.BspData = None


    def _deserialize(self, params):
        if params.get("BspData") is not None:
            self.BspData = InputKolBspData()
            self.BspData._deserialize(params.get("BspData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DetectFraudKOLResponse(AbstractModel):
    """DetectFraudKOL返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 回包数据
注意：此字段可能返回 null，表示取不到有效值。\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputKolData`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputKolData()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class EnhanceTaDegreeRequest(AbstractModel):
    """EnhanceTaDegree请求参数结构体

    """

    def __init__(self):
        """
        :param BspData: 业务数据\n        :type BspData: :class:`tencentcloud.taf.v20200210.models.InputTaBspData`\n        """
        self.BspData = None


    def _deserialize(self, params):
        if params.get("BspData") is not None:
            self.BspData = InputTaBspData()
            self.BspData._deserialize(params.get("BspData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class EnhanceTaDegreeResponse(AbstractModel):
    """EnhanceTaDegree返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 回包数据
注意：此字段可能返回 null，表示取不到有效值。\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputTaData`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputTaData()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class InputKolBspData(AbstractModel):
    """CheckKol

    """

    def __init__(self):
        """
        :param DataList: BspData\n        :type DataList: list of InputKolDataList\n        """
        self.DataList = None


    def _deserialize(self, params):
        if params.get("DataList") is not None:
            self.DataList = []
            for item in params.get("DataList"):
                obj = InputKolDataList()
                obj._deserialize(item)
                self.DataList.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InputKolDataList(AbstractModel):
    """CheckKol

    """

    def __init__(self):
        """
        :param Type: 账号类型[1：微信；2：qq；3：微博]\n        :type Type: int\n        :param Id: KOL账号ID[比如微信公众号ID]\n        :type Id: str\n        :param Name: KOL名称\n        :type Name: str\n        :param Phone: 手机号\n        :type Phone: str\n        :param AgentInfo: 代理商名称\n        :type AgentInfo: str\n        """
        self.Type = None
        self.Id = None
        self.Name = None
        self.Phone = None
        self.AgentInfo = None


    def _deserialize(self, params):
        self.Type = params.get("Type")
        self.Id = params.get("Id")
        self.Name = params.get("Name")
        self.Phone = params.get("Phone")
        self.AgentInfo = params.get("AgentInfo")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InputRecognizeEffectiveFlow(AbstractModel):
    """接口入参

    """


class InputRecognizeTargetAudience(AbstractModel):
    """流量反欺诈-验准入参

    """

    def __init__(self):
        """
        :param Uid: 设备ID，AccountType指定的类型\n        :type Uid: str\n        :param AccountType: 设备号类型，1.imei 2.imeiMd5（小写后转MD5转小写）3.idfa， 4.idfaMd5（大写后转MD5转小写），5.手机号,256.其它\n        :type AccountType: int\n        :param ModelIdList: 模型ID列表\n        :type ModelIdList: list of int\n        :param Ip: 用户IP\n        :type Ip: str\n        :param Os: 操作系统类型(unknown，android，ios，windows)\n        :type Os: str\n        :param Osv: 操作系统版本\n        :type Osv: str\n        :param Lat: 纬度\n        :type Lat: str\n        :param Lon: 经度\n        :type Lon: str\n        :param DeviceModel: 设备型号(MI 6)\n        :type DeviceModel: str\n        :param BidFloor: 竞价底价\n        :type BidFloor: int\n        :param Age: 年龄\n        :type Age: int\n        :param Gender: 性别(1.MALE 2.FEMALE)\n        :type Gender: int\n        :param Location: 用户地址\n        :type Location: str\n        :param DeliveryMode: 投放模式（0=PDB，1=PD，2=RTB，10=其他）\n        :type DeliveryMode: int\n        :param AdvertisingType: 广告位类型<br />（0=前贴片，1=开屏广告，2=网页头部广告、3=网页中部广告、4=网页底部广告、5=悬浮广告、10=其它）\n        :type AdvertisingType: int\n        :param Mac: mac地址，建议提供\n        :type Mac: str\n        :param Phone: 电话号码\n        :type Phone: str\n        :param Ua: 浏览器类型\n        :type Ua: str\n        :param App: 客户端应用\n        :type App: str\n        :param Package: 应用包名\n        :type Package: str\n        :param Maker: 设备制造商\n        :type Maker: str\n        :param DeviceType: 设备类型（PHONE,TABLET）\n        :type DeviceType: str\n        :param AccessMode: 入网方式(wifi,4g,3g,2g)\n        :type AccessMode: str\n        :param Sp: 运营商(1.移动 2.联通 3.电信等)\n        :type Sp: int\n        :param DeviceW: 设备屏幕分辨率宽度像素数\n        :type DeviceW: int\n        :param DeviceH: 设备屏幕分辨率高度像素数\n        :type DeviceH: int\n        :param FullScreen: 是否全屏插广告(0-否，1-是)\n        :type FullScreen: int\n        :param ImpBannerW: 广告位宽度\n        :type ImpBannerW: int\n        :param ImpBannerH: 广告位高度\n        :type ImpBannerH: int\n        :param Url: 网址\n        :type Url: str\n        :param Context: 上下文信息\n        :type Context: str\n        :param Channel: 渠道\n        :type Channel: str\n        :param ReqId: 请求ID\n        :type ReqId: str\n        :param ReqMd5: 请求ID的md5值\n        :type ReqMd5: str\n        :param AdType: ad_type\n        :type AdType: int\n        :param AppName: app name\n        :type AppName: str\n        :param AppVer: appVer\n        :type AppVer: str\n        :param ReqType: 竞价模式1：rtb 2:pd\n        :type ReqType: int\n        """
        self.Uid = None
        self.AccountType = None
        self.ModelIdList = None
        self.Ip = None
        self.Os = None
        self.Osv = None
        self.Lat = None
        self.Lon = None
        self.DeviceModel = None
        self.BidFloor = None
        self.Age = None
        self.Gender = None
        self.Location = None
        self.DeliveryMode = None
        self.AdvertisingType = None
        self.Mac = None
        self.Phone = None
        self.Ua = None
        self.App = None
        self.Package = None
        self.Maker = None
        self.DeviceType = None
        self.AccessMode = None
        self.Sp = None
        self.DeviceW = None
        self.DeviceH = None
        self.FullScreen = None
        self.ImpBannerW = None
        self.ImpBannerH = None
        self.Url = None
        self.Context = None
        self.Channel = None
        self.ReqId = None
        self.ReqMd5 = None
        self.AdType = None
        self.AppName = None
        self.AppVer = None
        self.ReqType = None


    def _deserialize(self, params):
        self.Uid = params.get("Uid")
        self.AccountType = params.get("AccountType")
        self.ModelIdList = params.get("ModelIdList")
        self.Ip = params.get("Ip")
        self.Os = params.get("Os")
        self.Osv = params.get("Osv")
        self.Lat = params.get("Lat")
        self.Lon = params.get("Lon")
        self.DeviceModel = params.get("DeviceModel")
        self.BidFloor = params.get("BidFloor")
        self.Age = params.get("Age")
        self.Gender = params.get("Gender")
        self.Location = params.get("Location")
        self.DeliveryMode = params.get("DeliveryMode")
        self.AdvertisingType = params.get("AdvertisingType")
        self.Mac = params.get("Mac")
        self.Phone = params.get("Phone")
        self.Ua = params.get("Ua")
        self.App = params.get("App")
        self.Package = params.get("Package")
        self.Maker = params.get("Maker")
        self.DeviceType = params.get("DeviceType")
        self.AccessMode = params.get("AccessMode")
        self.Sp = params.get("Sp")
        self.DeviceW = params.get("DeviceW")
        self.DeviceH = params.get("DeviceH")
        self.FullScreen = params.get("FullScreen")
        self.ImpBannerW = params.get("ImpBannerW")
        self.ImpBannerH = params.get("ImpBannerH")
        self.Url = params.get("Url")
        self.Context = params.get("Context")
        self.Channel = params.get("Channel")
        self.ReqId = params.get("ReqId")
        self.ReqMd5 = params.get("ReqMd5")
        self.AdType = params.get("AdType")
        self.AppName = params.get("AppName")
        self.AppVer = params.get("AppVer")
        self.ReqType = params.get("ReqType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InputSendTrafficSecuritySmsMsg(AbstractModel):
    """业务入参

    """

    def __init__(self):
        """
        :param TaskId: 投放任务ID\n        :type TaskId: str\n        :param Mobiles: 手机号码列表（号码量<=200）\n        :type Mobiles: list of str\n        """
        self.TaskId = None
        self.Mobiles = None


    def _deserialize(self, params):
        self.TaskId = params.get("TaskId")
        self.Mobiles = params.get("Mobiles")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class InputTaBspData(AbstractModel):
    """流量反欺诈-虚假TA识别

    """

    def __init__(self):
        """
        :param Seq: 请求序列号\n        :type Seq: int\n        :param OsType: 操作系统类型[0：未知；1：android；2：ios；3：windows]\n        :type OsType: str\n        :param AgeFloor: 年龄下限\n        :type AgeFloor: int\n        :param AgeCeil: 年龄上限\n        :type AgeCeil: int\n        :param Gender: 性别[1：男；2：女]\n        :type Gender: int\n        :param UserTime: 用户操作时间\n        :type UserTime: int\n        :param Imei: Imei [在(Imei|ImeiMd5|Idfa|IdfaMd5)里面4选1]\n        :type Imei: str\n        :param ImeiMd5: Imei小写后加密Md5 [在(Imei|ImeiMd5|Idfa|IdfaMd5)里面4选1]\n        :type ImeiMd5: str\n        :param Idfa: Idfa [在(Imei|ImeiMd5|Idfa|IdfaMd5)里面4选1]\n        :type Idfa: str\n        :param IdfaMd5: Idfa大写后加密Md5 [在(Imei|ImeiMd5|Idfa|IdfaMd5)里面4选1]\n        :type IdfaMd5: str\n        :param UserIp: 用户IP\n        :type UserIp: str\n        :param Mac: MAC地址[建议提供]\n        :type Mac: str\n        :param PhoneNum: 手机号码[中国大陆]\n        :type PhoneNum: str\n        :param UserAgent: 浏览器\n        :type UserAgent: str\n        :param App: APP名称\n        :type App: str\n        :param Package: 应用安装包名称\n        :type Package: str\n        :param DeviceMaker: 设备制造商\n        :type DeviceMaker: str\n        :param DeviceModule: 设备型号\n        :type DeviceModule: str\n        :param AccessMode: 入网方式[1：WIFI；2：4G；3：3G；4：2G；5：其它]\n        :type AccessMode: str\n        :param Sp: 运营商[1：移动；2：联通；3：电信；4：其它]\n        :type Sp: str\n        :param Url: 网址\n        :type Url: str\n        :param Location: 用户地址\n        :type Location: str\n        :param Latitude: 纬度\n        :type Latitude: str\n        :param Longitude: 精度\n        :type Longitude: str\n        :param Context: 辅助区分信息\n        :type Context: str\n        """
        self.Seq = None
        self.OsType = None
        self.AgeFloor = None
        self.AgeCeil = None
        self.Gender = None
        self.UserTime = None
        self.Imei = None
        self.ImeiMd5 = None
        self.Idfa = None
        self.IdfaMd5 = None
        self.UserIp = None
        self.Mac = None
        self.PhoneNum = None
        self.UserAgent = None
        self.App = None
        self.Package = None
        self.DeviceMaker = None
        self.DeviceModule = None
        self.AccessMode = None
        self.Sp = None
        self.Url = None
        self.Location = None
        self.Latitude = None
        self.Longitude = None
        self.Context = None


    def _deserialize(self, params):
        self.Seq = params.get("Seq")
        self.OsType = params.get("OsType")
        self.AgeFloor = params.get("AgeFloor")
        self.AgeCeil = params.get("AgeCeil")
        self.Gender = params.get("Gender")
        self.UserTime = params.get("UserTime")
        self.Imei = params.get("Imei")
        self.ImeiMd5 = params.get("ImeiMd5")
        self.Idfa = params.get("Idfa")
        self.IdfaMd5 = params.get("IdfaMd5")
        self.UserIp = params.get("UserIp")
        self.Mac = params.get("Mac")
        self.PhoneNum = params.get("PhoneNum")
        self.UserAgent = params.get("UserAgent")
        self.App = params.get("App")
        self.Package = params.get("Package")
        self.DeviceMaker = params.get("DeviceMaker")
        self.DeviceModule = params.get("DeviceModule")
        self.AccessMode = params.get("AccessMode")
        self.Sp = params.get("Sp")
        self.Url = params.get("Url")
        self.Location = params.get("Location")
        self.Latitude = params.get("Latitude")
        self.Longitude = params.get("Longitude")
        self.Context = params.get("Context")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputKolData(AbstractModel):
    """CheckKol

    """

    def __init__(self):
        """
        :param Code: 错误码[0:成功；非0：失败的错误码]
注意：此字段可能返回 null，表示取不到有效值。\n        :type Code: int\n        :param Message: 错误信息
注意：此字段可能返回 null，表示取不到有效值。\n        :type Message: str\n        :param Value: 业务返回数据
注意：此字段可能返回 null，表示取不到有效值。\n        :type Value: list of OutputKolValue\n        """
        self.Code = None
        self.Message = None
        self.Value = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        if params.get("Value") is not None:
            self.Value = []
            for item in params.get("Value"):
                obj = OutputKolValue()
                obj._deserialize(item)
                self.Value.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputKolValue(AbstractModel):
    """CheckKol

    """

    def __init__(self):
        """
        :param Id: KOL账号ID[比如微信公众号ID]
注意：此字段可能返回 null，表示取不到有效值。\n        :type Id: str\n        :param IsCheck: 是否查得[0：未查得；1：查得]
注意：此字段可能返回 null，表示取不到有效值。\n        :type IsCheck: int\n        :param FraudPScore: 作弊的可能性[0～100]
注意：此字段可能返回 null，表示取不到有效值。\n        :type FraudPScore: int\n        :param EvilPScore: 作弊的严重性[0～100]
注意：此字段可能返回 null，表示取不到有效值。\n        :type EvilPScore: int\n        """
        self.Id = None
        self.IsCheck = None
        self.FraudPScore = None
        self.EvilPScore = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        self.IsCheck = params.get("IsCheck")
        self.FraudPScore = params.get("FraudPScore")
        self.EvilPScore = params.get("EvilPScore")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputRecognizeEffectiveFlow(AbstractModel):
    """业务出参

    """

    def __init__(self):
        """
        :param Code: 返回码。0表示成功，非0标识失败错误码
注意：此字段可能返回 null，表示取不到有效值。\n        :type Code: int\n        :param Message: UTF-8编码，出错消息。
注意：此字段可能返回 null，表示取不到有效值。\n        :type Message: str\n        :param Value: 业务入参
注意：此字段可能返回 null，表示取不到有效值。\n        :type Value: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeEffectiveFlowValue`\n        """
        self.Code = None
        self.Message = None
        self.Value = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        if params.get("Value") is not None:
            self.Value = OutputRecognizeEffectiveFlowValue()
            self.Value._deserialize(params.get("Value"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputRecognizeEffectiveFlowValue(AbstractModel):
    """业务出参

    """

    def __init__(self):
        """
        :param Lable: 返回标签
注意：此字段可能返回 null，表示取不到有效值。\n        :type Lable: str\n        :param Score: 返回分值
注意：此字段可能返回 null，表示取不到有效值。\n        :type Score: float\n        """
        self.Lable = None
        self.Score = None


    def _deserialize(self, params):
        self.Lable = params.get("Lable")
        self.Score = params.get("Score")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputRecognizeTargetAudience(AbstractModel):
    """流量反欺诈-验准返回值

    """

    def __init__(self):
        """
        :param Code: 返回码（0，成功，其他失败）\n        :type Code: int\n        :param Message: 返回码对应的信息
注意：此字段可能返回 null，表示取不到有效值。\n        :type Message: str\n        :param Value: 返回模型结果
注意：此字段可能返回 null，表示取不到有效值。\n        :type Value: list of OutputRecognizeTargetAudienceValue\n        """
        self.Code = None
        self.Message = None
        self.Value = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        if params.get("Value") is not None:
            self.Value = []
            for item in params.get("Value"):
                obj = OutputRecognizeTargetAudienceValue()
                obj._deserialize(item)
                self.Value.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputRecognizeTargetAudienceValue(AbstractModel):
    """流量反欺诈-验准返回的查询分值

    """

    def __init__(self):
        """
        :param ModelId: 模型ID
注意：此字段可能返回 null，表示取不到有效值。\n        :type ModelId: int\n        :param IsFound: 是否正常返回结果
注意：此字段可能返回 null，表示取不到有效值。\n        :type IsFound: int\n        :param Score: 返回分值
注意：此字段可能返回 null，表示取不到有效值。\n        :type Score: float\n        """
        self.ModelId = None
        self.IsFound = None
        self.Score = None


    def _deserialize(self, params):
        self.ModelId = params.get("ModelId")
        self.IsFound = params.get("IsFound")
        self.Score = params.get("Score")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputSendTrafficSecuritySmsMsg(AbstractModel):
    """返回结果

    """

    def __init__(self):
        """
        :param Code: 返回码（0：接口调用成功 非0：接口调用失败）\n        :type Code: int\n        :param Message: 返回码对应的信息
注意：此字段可能返回 null，表示取不到有效值。\n        :type Message: str\n        :param Value: 发送失败的号码列表
注意：此字段可能返回 null，表示取不到有效值。\n        :type Value: list of str\n        """
        self.Code = None
        self.Message = None
        self.Value = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        self.Value = params.get("Value")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputTaData(AbstractModel):
    """流量反欺诈-虚假TA识别

    """

    def __init__(self):
        """
        :param Code: 错误码[0:成功；非0：失败的错误码]\n        :type Code: int\n        :param Message: 错误信息
注意：此字段可能返回 null，表示取不到有效值。\n        :type Message: str\n        :param Value: 结果数据
注意：此字段可能返回 null，表示取不到有效值。\n        :type Value: :class:`tencentcloud.taf.v20200210.models.OutputTaValue`\n        """
        self.Code = None
        self.Message = None
        self.Value = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        if params.get("Value") is not None:
            self.Value = OutputTaValue()
            self.Value._deserialize(params.get("Value"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OutputTaValue(AbstractModel):
    """流量反欺诈-虚假TA识别

    """

    def __init__(self):
        """
        :param IsCheck: 是否查得[0：未查得；1：查得]
注意：此字段可能返回 null，表示取不到有效值。\n        :type IsCheck: int\n        :param IsMatch: 是否符合[0：不符合；1：符合]
注意：此字段可能返回 null，表示取不到有效值。\n        :type IsMatch: int\n        """
        self.IsCheck = None
        self.IsMatch = None


    def _deserialize(self, params):
        self.IsCheck = params.get("IsCheck")
        self.IsMatch = params.get("IsMatch")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RecognizeCustomizedAudienceRequest(AbstractModel):
    """RecognizeCustomizedAudience请求参数结构体

    """

    def __init__(self):
        """
        :param BspData: 业务入参\n        :type BspData: :class:`tencentcloud.taf.v20200210.models.InputRecognizeTargetAudience`\n        """
        self.BspData = None


    def _deserialize(self, params):
        if params.get("BspData") is not None:
            self.BspData = InputRecognizeTargetAudience()
            self.BspData._deserialize(params.get("BspData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RecognizeCustomizedAudienceResponse(AbstractModel):
    """RecognizeCustomizedAudience返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 业务出参
注意：此字段可能返回 null，表示取不到有效值。\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeTargetAudience`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputRecognizeTargetAudience()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class RecognizeEffectiveFlowRequest(AbstractModel):
    """RecognizeEffectiveFlow请求参数结构体

    """

    def __init__(self):
        """
        :param BusinessSecurityData: 业务入参\n        :type BusinessSecurityData: :class:`tencentcloud.taf.v20200210.models.InputRecognizeEffectiveFlow`\n        """
        self.BusinessSecurityData = None


    def _deserialize(self, params):
        if params.get("BusinessSecurityData") is not None:
            self.BusinessSecurityData = InputRecognizeEffectiveFlow()
            self.BusinessSecurityData._deserialize(params.get("BusinessSecurityData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RecognizeEffectiveFlowResponse(AbstractModel):
    """RecognizeEffectiveFlow返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 业务出参\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeEffectiveFlow`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputRecognizeEffectiveFlow()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class RecognizePreciseTargetAudienceRequest(AbstractModel):
    """RecognizePreciseTargetAudience请求参数结构体

    """

    def __init__(self):
        """
        :param BspData: 业务数据\n        :type BspData: :class:`tencentcloud.taf.v20200210.models.InputRecognizeTargetAudience`\n        """
        self.BspData = None


    def _deserialize(self, params):
        if params.get("BspData") is not None:
            self.BspData = InputRecognizeTargetAudience()
            self.BspData._deserialize(params.get("BspData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RecognizePreciseTargetAudienceResponse(AbstractModel):
    """RecognizePreciseTargetAudience返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 回包数据
注意：此字段可能返回 null，表示取不到有效值。\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeTargetAudience`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputRecognizeTargetAudience()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class RecognizeTargetAudienceRequest(AbstractModel):
    """RecognizeTargetAudience请求参数结构体

    """

    def __init__(self):
        """
        :param BspData: 业务数据\n        :type BspData: :class:`tencentcloud.taf.v20200210.models.InputRecognizeTargetAudience`\n        """
        self.BspData = None


    def _deserialize(self, params):
        if params.get("BspData") is not None:
            self.BspData = InputRecognizeTargetAudience()
            self.BspData._deserialize(params.get("BspData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RecognizeTargetAudienceResponse(AbstractModel):
    """RecognizeTargetAudience返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 回包数据
注意：此字段可能返回 null，表示取不到有效值。\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputRecognizeTargetAudience`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputRecognizeTargetAudience()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class SendTrafficSecuritySmsMessageRequest(AbstractModel):
    """SendTrafficSecuritySmsMessage请求参数结构体

    """

    def __init__(self):
        """
        :param BspData: 业务入参\n        :type BspData: :class:`tencentcloud.taf.v20200210.models.InputSendTrafficSecuritySmsMsg`\n        """
        self.BspData = None


    def _deserialize(self, params):
        if params.get("BspData") is not None:
            self.BspData = InputSendTrafficSecuritySmsMsg()
            self.BspData._deserialize(params.get("BspData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SendTrafficSecuritySmsMessageResponse(AbstractModel):
    """SendTrafficSecuritySmsMessage返回参数结构体

    """

    def __init__(self):
        """
        :param Data: 返回结果
注意：此字段可能返回 null，表示取不到有效值。\n        :type Data: :class:`tencentcloud.taf.v20200210.models.OutputSendTrafficSecuritySmsMsg`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = OutputSendTrafficSecuritySmsMsg()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 用量消息推送失败。
FAILEDOPERATION_PUSHUSAGEMESSAGEERROR = 'FailedOperation.PushUsageMessageError'

# 服务未开通。
FAILEDOPERATION_SERVICENOTOPEN = 'FailedOperation.ServiceNotOpen'

# 未知错误。
FAILEDOPERATION_UNKNOWNERROR = 'FailedOperation.UnknownError'

# 内部错误。
INTERNALERROR = 'InternalError'

# 图片ocr识别异常。
INTERNALERROR_IMAGEOCRERROR = 'InternalError.ImageOcrError'

# 图片处理异常。
INTERNALERROR_IMAGEPROCESSERROR = 'InternalError.ImageProcessError'

# 服务调用超时。
INTERNALERROR_SERVERTIMEOUTERROR = 'InternalError.ServerTimeOutError'

# 报告结构化异常。
INTERNALERROR_STRUCTIONERROR = 'InternalError.StructionError'

# 报告文本分类异常。
INTERNALERROR_TEXTCLASSIFYERROR = 'InternalError.TextClassifyError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数AutoFitDirection无效。
INVALIDPARAMETER_AUTOFITDIRECTION = 'InvalidParameter.AutoFitDirection'

# 参数ImageInfoList无效。
INVALIDPARAMETER_IMAGEINFOLIST = 'InvalidParameter.ImageInfoList'

# 参数ImageOriginalSize无效。
INVALIDPARAMETER_IMAGEORIGINALSIZE = 'InvalidParameter.ImageOriginalSize'

# 请求Action无效。
INVALIDPARAMETER_INVALIDACTION = 'InvalidParameter.InvalidAction'

# 参数OcrEngineType无效。
INVALIDPARAMETER_OCRENGINETYPE = 'InvalidParameter.OcrEngineType'

# 参数RotateTheAngle无效。
INVALIDPARAMETER_ROTATETHEANGLE = 'InvalidParameter.RotateTheAngle'

# 参数Text无效。
INVALIDPARAMETER_TEXT = 'InvalidParameter.Text'

# 图片base64编码错误。
INVALIDPARAMETERVALUE_IMAGECODEERROR = 'InvalidParameterValue.ImageCodeError'

# 图片编码无效。
INVALIDPARAMETERVALUE_IMAGECODEINVALID = 'InvalidParameterValue.ImageCodeInvalid'

# 图片没有文字。
INVALIDPARAMETERVALUE_IMAGEISNOTEXT = 'InvalidParameterValue.ImageIsNoText'

# 图片URL无效。
INVALIDPARAMETERVALUE_IMAGEURLINVALID = 'InvalidParameterValue.ImageURLInvalid'

# 文本参数无效。
INVALIDPARAMETERVALUE_TEXTISNEED = 'InvalidParameterValue.TextIsNeed'

# 服务流量超过限制。
LIMITEXCEEDED_SERVERLIMITEXCEEDED = 'LimitExceeded.ServerLimitExceeded'

# 缺少图片参数。
MISSINGPARAMETER_IMAGEISNEED = 'MissingParameter.ImageIsNeed'

# 图片大小超过限制。
OPERATIONDENIED_IMAGETOOLARGE = 'OperationDenied.ImageTooLarge'

# 不支持的报告类型。
OPERATIONDENIED_UNSUPPORTTHISTYPE = 'OperationDenied.UnSupportThisType'

# 请求速度超过限制。
REQUESTLIMITEXCEEDED_QPSLIMITEXCEEDED = 'RequestLimitExceeded.QPSLimitExceeded'

# 当前无权限，请检查BisinsessId。
UNAUTHORIZEDOPERATION_PERMISSIONDENIEDERROR = 'UnauthorizedOperation.PermissionDeniedError'

# 当前报告类型不支持。
UNSUPPORTEDOPERATION_UNSUPPORTTHISTYPE = 'UnsupportedOperation.UnSupportThisType'
